summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAllison Easton <allison.easton@mongodb.com>2021-09-17 07:50:11 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2021-09-17 08:22:51 +0000
commitf508575e0a4f72979247176c279c5497da0a260a (patch)
treed5d56d0e8e3bd61767221796a2519a0eaa3533ca
parent913a6ef396fbca336548ac2994a4a56c227016c3 (diff)
downloadmongo-f508575e0a4f72979247176c279c5497da0a260a.tar.gz
SERVER-60008 Disable the distributed lock ping thread in lagged_config_secondary.js
-rw-r--r--jstests/sharding/lagged_config_secondary.js16
1 files changed, 11 insertions, 5 deletions
diff --git a/jstests/sharding/lagged_config_secondary.js b/jstests/sharding/lagged_config_secondary.js
index c5b68740b0b..196ca38f537 100644
--- a/jstests/sharding/lagged_config_secondary.js
+++ b/jstests/sharding/lagged_config_secondary.js
@@ -14,16 +14,22 @@ TestData.skipCheckOrphans = true;
(function() {
/* On the config server the lastApplied optime can go past the atClusterTime timestamp due to pings
* made on collection config.mongos by sharding uptime reporter thread.
* Hence, it will not write the no-op oplog entry on the config server as part of waiting for read
* concern. For more deterministic testing of no-op writes to the oplog, disable uptime reporter
* threads from reaching out to the config server.
*/
+const failpointParams = {
+ setParameter: {"failpoint.disableReplSetDistLockManager": "{mode: 'alwaysOn'}"}
+};
+
var st = new ShardingTest({
shards: 1,
configReplSetTestOptions: {settings: {chainingAllowed: false}},
other: {
+ configOptions: failpointParams,
+ rsOptions: failpointParams,
mongosOptions:
{setParameter: {["failpoint.disableShardingUptimeReporting"]: "{mode: 'alwaysOn'}"}}
}
@@ -14,16 +14,22 @@ TestData.skipCheckOrphans = true;
(function() {
-/* On the config server the lastApplied optime can go past the atClusterTime timestamp due to pings
- * made on collection config.mongos by sharding uptime reporter thread.
- * Hence, it will not write the no-op oplog entry on the config server as part of waiting for read
- * concern. For more deterministic testing of no-op writes to the oplog, disable uptime reporter
- * threads from reaching out to the config server.
+/**
+ * On the config server the lastApplied optime can go past the atClusterTime timestamp due to pings
+ * made on collection config.mongos or config.lockping by the distributed lock pinger thread and
+ * sharding uptime reporter thread. This can cause the insert into test.TestConfigColl to time out.
+ * To prevent this, disable the pinger threads to prevent them reaching out to the config server.
*/